@@ -10,12 +10,12 @@ void calcX_G(Matrix<double> X_design_G [], int *offid, int noff , int *ndam, int
         int off_poss;
         int sire_poss;
         int dam_poss;
-        int o1;
-        int o2;
-        int d1;
-        int d2;
-        int s1;
-        int s2;
+        int o1=0;
+        int o2=0;
+        int d1=0;
+        int d2=0;
+        int s1=0;
+        int s2=0;
         double o1inp;
         double o2inp;
         double sl;
@@ -55,7 +55,6 @@ void calcX_G(Matrix<double> X_design_G [], int *offid, int noff , int *ndam, int
                sire_poss = Sires_vec[i][s];           // gets position of sire genotype in G   
 
                if(sire_poss<nind){     
-
                  s1 = G[sire_poss][l*2];
                  s2 = G[sire_poss][(l*2)+1]; 
                }
